#!/bin/bash
FWDL_DB_COPY_LOG=/etc/fabos/Dcmd/fwdl_db_copy_log

log_to_pg_file() {

    log_file=${FWDL_DB_COPY_LOG}
    if [ $# -ge 1 ]; then
        log_txt="$*"
    else
        log_txt=""
    fi

    if [ -f ${log_file} ]; then
        echo "`date` : ${log_txt}" >> ${log_file}
    fi
}

# Obtain previous and current firmware versions,
if [ -f /etc/fabos/Dcmd/FirmwareVersions ]; then
    firmwareVersions=(`cat /etc/fabos/Dcmd/FirmwareVersions`)
    # Prev fw version is the first entry, current fw version is the next entry
    prevFwVersion=${firmwareVersions[0]}
    currFwVersion=${firmwareVersions[1]}
fi

# Set default values if version info cannot be obtained
if [ -z "${prevFwVersion}" ]; then
    prevFwVersion="0.0.0"
fi
if [ -z "${currFwVersion}" ]; then
    currFwVersion="0.0.0"
fi

if [ -f ${FWDL_DB_COPY_LOG} ]; then
    log_to_pg_file "SchemaConversionDwnGrd.sh : file check passed"
else
    touch ${FWDL_DB_COPY_LOG} 2>/dev/null
fi

log_to_pg_file SchemaConversionDwnGrd.sh : Previous Fw Version $prevFwVersion
log_to_pg_file SchemaConversionDwnGrd.sh : Current Fw Version $currFwVersion

if [ "v4.0.0" == v"${currFwVersion}" -a "v4.1.0" == v"${prevFwVersion}" ]; then
    log_to_pg_file "SchemaConversionDwnGrd.sh : Removing all Config as DB conversion is not supported while Downgrade from 4.1.0 to 4.0.0" 
    echo "SchemaConversionDwnGrd.sh : Removing all Config as DB conversion is not supported while Downgrade from 4.1.0 to 4.0.0"
    rm -rf /etc/fabos/Dcmd/*cfg /etc/fabos/Dcmd/*cfg.bk
    rm -rf /etc/fabos/Ccmd/*cfg /etc/fabos/Dcmd/*cfg.bk
fi

if [ "v4.0.0" == v"${currFwVersion}" -a "v4.1.1" == v"${prevFwVersion}" ]; then
    log_to_pg_file "SchemaConversionDwnGrd.sh : Removing all Config as DB conversion is not supported while Downgrade from 4.1.1 to 4.0.0" 
    echo "SchemaConversionDwnGrd.sh : Removing all Config as DB conversion is not supported while Downgrade from 4.1.1 to 4.0.0"
    rm -rf /etc/fabos/Dcmd/*cfg /etc/fabos/Dcmd/*cfg.bk
    rm -rf /etc/fabos/Ccmd/*cfg /etc/fabos/Dcmd/*cfg.bk
fi
