create or replace function wavecurrent.CONTAINS_ONE ( RANGE_TEXT text, VALUE int ) returns boolean as $$
declare
    PARTS text array;
    HYPHEN_POS int;
    PART text;
    PART1 int;
    PART2 int;
begin
    if RANGE_TEXT is null or RANGE_TEXT = '' then
        return false;
    end if;

    PARTS := regexp_split_to_array( RANGE_TEXT, ',' );

    foreach PART in array PARTS
    loop
        HYPHEN_POS = strpos( PART, '-' );
        if HYPHEN_POS < 1 then
            if cast( PART as int ) = VALUE then
                return true;
            end if;
        else
            PART1 := cast( left( PART, HYPHEN_POS-1 ) as int );
            PART2 := cast( substr( PART, HYPHEN_POS+1 ) as int );

            if VALUE >= PART1 and VALUE <= PART2 then
                return true;
            end if;
        end if;
    end loop;

    return false;
end;
$$ language plpgsql;

create or replace function wavecurrent.CONTAINS ( RANGE_TEXT text, RANGE_SEARCH_TEXT text, RANGE_CRITERIA text) returns boolean as $$
declare
    PARTS           text array;
    HYPHEN_POS      int;
    VALUE           int;
    FOUND           boolean;
    RETURN_VALUE    boolean;
    PART            text;
    PART1           int;
    PART2           int;
    ITER            int;
begin
    if RANGE_SEARCH_TEXT is null or RANGE_SEARCH_TEXT = '' then
        return false;
    end if;

    if RANGE_TEXT is null or RANGE_TEXT = '' then
        return false;
    end if;

    PARTS := regexp_split_to_array( RANGE_SEARCH_TEXT, ',' );

    RETURN_VALUE := false;
    foreach PART in array PARTS
    loop
        HYPHEN_POS = strpos( PART, '-' );
        if HYPHEN_POS < 1 then
            VALUE := cast( PART as int );
            PART1 := VALUE;
            PART2 := VALUE;
        else
            PART1 := cast( left( PART, HYPHEN_POS-1 ) as int );
            PART2 := cast( substr( PART, HYPHEN_POS+1 ) as int );
        end if;

        ITER := PART1;
        WHILE ITER <= PART2 LOOP

            EXECUTE 'SELECT wavecurrent.contains_one ($1, $2)' INTO FOUND USING RANGE_TEXT, ITER;

            if FOUND then
                RETURN_VALUE := true;
                if RANGE_CRITERIA = 'any' then
                    return RETURN_VALUE;
                end if;
            else
                RETURN_VALUE := false;
                if RANGE_CRITERIA = 'all' then
                    return RETURN_VALUE;
                end if;
            end if;

            ITER := ITER + 1;
                
        END LOOP;

    end loop;
    return RETURN_VALUE;

end;
$$ language plpgsql;

create or replace function wavecurrent.CONTAINS_ALL ( RANGE_TEXT text, RANGE_SEARCH_TEXT text) returns boolean as $$
declare
    RETURN_VALUE    boolean;
begin
    EXECUTE 'SELECT wavecurrent.contains ($1, $2, $3)' INTO RETURN_VALUE USING RANGE_TEXT, RANGE_SEARCH_TEXT, 'all';
    return RETURN_VALUE;
end;
$$ language plpgsql;

create or replace function wavecurrent.CONTAINS_ANY ( RANGE_TEXT text, RANGE_SEARCH_TEXT text) returns boolean as $$
declare
    RETURN_VALUE    boolean;
begin
    EXECUTE 'SELECT wavecurrent.contains ($1, $2, $3)' INTO RETURN_VALUE USING RANGE_TEXT, RANGE_SEARCH_TEXT, 'any';
    return RETURN_VALUE;
end;
$$ language plpgsql;

create or replace function wavecurrent.CONTAINS_NONE ( RANGE_TEXT text, RANGE_SEARCH_TEXT text) returns boolean as $$
declare
    RETURN_VALUE    boolean;
begin
    EXECUTE 'SELECT NOT wavecurrent.contains_any ($1, $2)' INTO RETURN_VALUE USING RANGE_TEXT, RANGE_SEARCH_TEXT;
    return RETURN_VALUE;
end;
$$ language plpgsql;
